aboutsummaryrefslogtreecommitdiffstats
path: root/phpBB/includes/db/dbal.php
diff options
context:
space:
mode:
authorMeik Sievertsen <acydburn@phpbb.com>2009-01-20 16:54:40 +0000
committerMeik Sievertsen <acydburn@phpbb.com>2009-01-20 16:54:40 +0000
commitdcd073bb44136ac0d22ade2a5ecf759e7e2ae3bc (patch)
tree7a0824e649e292e22a49839254c2b5173bac0c55 /phpBB/includes/db/dbal.php
parentcd4091af43fa2d7d3dbe5ad0d583c63f1d96c903 (diff)
downloadforums-dcd073bb44136ac0d22ade2a5ecf759e7e2ae3bc.tar
forums-dcd073bb44136ac0d22ade2a5ecf759e7e2ae3bc.tar.gz
forums-dcd073bb44136ac0d22ade2a5ecf759e7e2ae3bc.tar.bz2
forums-dcd073bb44136ac0d22ade2a5ecf759e7e2ae3bc.tar.xz
forums-dcd073bb44136ac0d22ade2a5ecf759e7e2ae3bc.zip
sqlite works now...
git-svn-id: file:///svn/phpbb/trunk@9282 89ea8834-ac86-4346-8a33-228a782c2dd0
Diffstat (limited to 'phpBB/includes/db/dbal.php')
-rw-r--r--phpBB/includes/db/dbal.php18
1 files changed, 9 insertions, 9 deletions
diff --git a/phpBB/includes/db/dbal.php b/phpBB/includes/db/dbal.php
index 99474635b6..e3588a9cd5 100644
--- a/phpBB/includes/db/dbal.php
+++ b/phpBB/includes/db/dbal.php
@@ -457,7 +457,7 @@ abstract class phpbb_dbal
/**
* Run DB-specific code to build SQL Report to explain queries, show statistics and runtime information. Called by {@link phpbb_dbal::sql_report() sql_report()}.
*
* This function only executes if the GET parameter 'explain' is true and DEBUG_EXTRA enabled.
*
* @param string $mode The mode to handle. 'display' is used for displaying the report, all other modes are internal.
* @param string $query Query to document/explain. Only used internally to build the plan.
@@ -483,7 +483,7 @@ abstract class phpbb_dbal
}
// EXPLAIN only in extra debug mode
- if (defined('DEBUG_EXTRA'))
+ if (phpbb::$base_config['debug_extra'])
{
$this->sql_report('start', $query);
}
@@ -499,7 +499,7 @@ abstract class phpbb_dbal
if ($this->query_result !== false)
{
- if (defined('DEBUG_EXTRA'))
+ if (phpbb::$base_config['debug_extra'])
{
$this->sql_report('fromcache', $query);
}
@@ -512,7 +512,7 @@ abstract class phpbb_dbal
$this->sql_error($query);
}
- if (defined('DEBUG_EXTRA'))
+ if (phpbb::$base_config['debug_extra'])
{
$this->sql_report('stop', $query);
}
@@ -1084,8 +1084,8 @@ abstract class phpbb_dbal
// Show complete SQL error and path to administrators only
// Additionally show complete error on installation or if extended debug mode is enabled
- // The DEBUG_EXTRA constant is for development only!
- if ((phpbb::registered('acl') && phpbb::$acl->acl_get('a_')) || defined('IN_INSTALL') || defined('DEBUG_EXTRA'))
+ // The phpbb::$base_config['debug_extra'] variable is for development only!
+ if ((phpbb::registered('acl') && phpbb::$acl->acl_get('a_')) || defined('IN_INSTALL') || phpbb::$base_config['debug_extra'])
{
$message .= ($sql) ? '<br /><br />SQL<br /><br />' . htmlspecialchars($sql) : '';
$message .= '<br />';
@@ -1139,7 +1139,7 @@ abstract class phpbb_dbal
/**
* Build SQL Report to explain queries, show statistics and runtime information.
*
* This function only executes if the GET parameter 'explain' is true and DEBUG_EXTRA enabled.
*
* @param string $mode The mode to handle. 'display' is used for displaying the report, all other modes are internal.
* @param string $query Query to document/explain. Only used internally to build the plan.
@@ -1354,7 +1354,7 @@ abstract class phpbb_dbal
$var_name = preg_replace('/[\n\r\s\t]+/', ' ', $query);
$var_name = md5($this->sql_layer . '_' . $var_name);
- $data = phpbb::$acm->get($var_name, 'sql');
+ $data = phpbb::$acm->get_sql($var_name);
if ($data !== false)
{
@@ -1398,7 +1398,7 @@ abstract class phpbb_dbal
}
$this->sql_freeresult($this->query_result);
- phpbb::$acm->put($var_name, $data, $cache_ttl, 'sql');
+ phpbb::$acm->put_sql($var_name, $data, $cache_ttl);
$this->query_result = ++$this->cache_index;
$this->cache_rowset[$this->query_result] = $data['rowset'];
@@ -457,7 +457,7 @@ abstract class phpbb_dbal
* Run DB-specific code to build SQL Report to explain queries, show statistics and runtime information. Called by {@link phpbb_dbal::sql_report() sql_report()}.
*
- * This function only executes if the GET parameter 'explain' is true and DEBUG_EXTRA enabled.
+ * This function only executes if the GET parameter 'explain' is true and phpbb::$base_config['debug_extra'] enabled.
*
* @param string $mode The mode to handle. 'display' is used for displaying the report, all other modes are internal.
@@ -1139,7 +1139,7 @@ abstract class phpbb_dbal
* Build SQL Report to explain queries, show statistics and runtime information.
*
- * This function only executes if the GET parameter 'explain' is true and DEBUG_EXTRA enabled.
+ * This function only executes if the GET parameter 'explain' is true and phpbb::$base_config['debug_extra'] enabled.
*
* @param string $mode The mode to handle. 'display' is used for displaying the report, all other modes are internal.